# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Speck(Component):
    """A Speck component.
The Speck component is a WebGL-based 3D molecule renderer.
Read more about the component here:
https://github.com/wwwtyro/speck

Keyword arguments:
- id (string; optional): The ID used to identify this component in Dash callbacks.
- data (list; optional): The xyz file data; a list of atoms such that each atom
has a dictionary defining the x, y, and z coordinates
along with the atom's symbol.
- scrollZoom (boolean; optional): The option of whether or not to allow scrolling to control
the zoom.
- view (optional): An object that determines and controls various parameters
related to how the molecule is displayed.. view has the following type: dict containing keys 'aspect', 'zoom', 'translation', 'atomScale', 'relativeAtomScale', 'bondScale', 'rotation', 'ao', 'aoRes', 'brightness', 'outline', 'spf', 'bonds', 'bondThreshold', 'bondShade', 'atomShade', 'resolution', 'dofStrength', 'dofPosition', 'fxaa'.
Those keys have the following types:
  - aspect (number; optional)
  - zoom (number; optional)
  - translation (optional): . translation has the following type: dict containing keys 'x', 'y'.
Those keys have the following types:
  - x (number; optional)
  - y (number; optional)
  - atomScale (number; optional)
  - relativeAtomScale (number; optional)
  - bondScale (number; optional)
  - rotation (list; optional)
  - ao (number; optional)
  - aoRes (number; optional)
  - brightness (number; optional)
  - outline (number; optional)
  - spf (number; optional)
  - bonds (boolean; optional)
  - bondThreshold (number; optional)
  - bondShade (number; optional)
  - atomShade (number; optional)
  - resolution (number; optional)
  - dofStrength (number; optional)
  - dofPosition (number; optional)
  - fxaa (number; optional)
- presetView (a value equal to: 'default', 'stickball', 'toon', 'licorice'; optional): One of several pre-loaded views: default, stick-ball, toon,
and licorice"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, scrollZoom=Component.UNDEFINED, view=Component.UNDEFINED, presetView=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'data', 'scrollZoom', 'view', 'presetView']
        self._type = 'Speck'
        self._namespace = 'dash_bio'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'data', 'scrollZoom', 'view', 'presetView']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Speck, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Molecule2dViewer(Component):
    """A Molecule2dViewer component.


Keyword arguments:
- id (string; optional): The ID used to identify this component in callbacks
- selectedAtomIds (list; optional): The selected atom IDs.
- width (number; optional): The width of the SVG element.
- height (number; optional): The height of the SVG element.
- modelData (optional): Description of the molecule to display.. modelData has the following type: dict containing keys 'nodes', 'links'.
Those keys have the following types:
  - nodes (list; optional)
  - links (list; optional)"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, selectedAtomIds=Component.UNDEFINED, width=Component.UNDEFINED, height=Component.UNDEFINED, modelData=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'selectedAtomIds', 'width', 'height', 'modelData']
        self._type = 'Molecule2dViewer'
        self._namespace = 'dash_bio'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'selectedAtomIds', 'width', 'height', 'modelData']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Molecule2dViewer, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class SequenceViewer(Component):
    """A SequenceViewer component.
The sequence viewer component is used to display sequences
that represent proteins, strands of genomic information, and
more. It can apply a coverage to the sequence supplied (with
clickable coverage sections that can display specific information,
and an optional legend to describe the color codes used),
search through the sequence for specific regex, capture
mouse selection events of subparts of the sequence, display a
count of the number of nucleotides or amino acids in the
sequence,
Read more about the component here:
https://github.com/FlyBase/react-sequence-viewer

Keyword arguments:
- id (string; optional): The ID used to identify this component in Dash callbacks.
- sequence (string; optional): The amino acid sequence that will be displayed.
- showLineNumbers (boolean; optional): The option of whether or not to display line numbers.
- wrapAminoAcids (boolean; optional): The option of whether or not to display the list of amino acids
as broken up into separate lines of a fixed length set by
charsPerLine.
- charsPerLine (number; optional): The number of amino acids that will display per line.
- toolbar (boolean; optional): The option of whether or not to display a toolbar at the top
that allows the user to choose the number of letters per line.
- search (boolean; optional): The option of whether or not to include a search bar in
the header. This supports regex.
- title (string; optional): A string that displays at the top of the component.
- sequenceMaxHeight (string; optional): The maximum height of the sequence.
- badge (boolean; optional): The option of whether or not to display a badge showing the
amino acid count at the top of the component beside the title.
- selection (list; optional): A highlighted section of the sequence; the color of the highlight
can also be defined. Takes a list of format [min, max, color] where
min is a number that represents the starting index of the selection,
max is a number that represents the stopping index of the selection,
and color is a string that defines the highlight color.
Cannot be used at the same time as coverage.
- coverage (list; optional): A coverage of the entire sequence; each section of the sequence
can have its own text color, background color, tooltip (on hover),
and an optional underscore. The props start and end represent the
beginning and terminating indices of the section in question.
Cannot be used at the same time as selection.
- legend (list; optional): A legend corresponding to the color codes above (optionally displayed).
- coverageClicked (number; optional): Contains the index of the section that was clicked last in
the coverage list supplied.
- mouseSelection (optional): Contains information about the subsequence selected
by the mouse. Start and end refer to the initial and
final indices, respectively, of the subsequence, and
"selection" contains the string that is selected.. mouseSelection has the following type: dict containing keys 'start', 'end', 'selection'.
Those keys have the following types:
  - start (number; optional)
  - end (number; optional)
  - selection (string; optional)
- subpartSelected (list; optional): A list of the subparts selected using the
"search" function or the "selection" property."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, sequence=Component.UNDEFINED, showLineNumbers=Component.UNDEFINED, wrapAminoAcids=Component.UNDEFINED, charsPerLine=Component.UNDEFINED, toolbar=Component.UNDEFINED, search=Component.UNDEFINED, title=Component.UNDEFINED, sequenceMaxHeight=Component.UNDEFINED, badge=Component.UNDEFINED, selection=Component.UNDEFINED, coverage=Component.UNDEFINED, legend=Component.UNDEFINED, coverageClicked=Component.UNDEFINED, mouseSelection=Component.UNDEFINED, subpartSelected=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'sequence', 'showLineNumbers', 'wrapAminoAcids', 'charsPerLine', 'toolbar', 'search', 'title', 'sequenceMaxHeight', 'badge', 'selection', 'coverage', 'legend', 'coverageClicked', 'mouseSelection', 'subpartSelected']
        self._type = 'SequenceViewer'
        self._namespace = 'dash_bio'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'sequence', 'showLineNumbers', 'wrapAminoAcids', 'charsPerLine', 'toolbar', 'search', 'title', 'sequenceMaxHeight', 'badge', 'selection', 'coverage', 'legend', 'coverageClicked', 'mouseSelection', 'subpartSelected']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(SequenceViewer, self).__init__(**args)



from .AlignmentChart import AlignmentChart
from .AlignmentViewer import AlignmentViewer
from .Circos import Circos
from .Ideogram import Ideogram
from .Molecule2dViewer import Molecule2dViewer
from .Molecule3dViewer import Molecule3dViewer
from .NeedlePlot import NeedlePlot
from .OncoPrint import OncoPrint
from .SequenceViewer import SequenceViewer
from .Speck import Speck

__all__ = [
    "AlignmentChart",
    "AlignmentViewer",
    "Circos",
    "Ideogram",
    "Molecule2dViewer",
    "Molecule3dViewer",
    "NeedlePlot",
    "OncoPrint",
    "SequenceViewer",
    "Speck"
]


import json
import os
from setuptools import setup
from io import open

filepath = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'README.md')
with open(filepath, encoding='utf-8') as f:
    long_description = f.read()

with open(os.path.join('dash_bio', 'package-info.json'), encoding='utf-8') as f:
    package = json.load(f)

package_name = package["name"].replace(" ", "_").replace("-", "_")

setup(
    name=package_name,
    version=package["version"],
    url='http://github.com/plotly/{}'.format(package_name.replace('_', '-')),
    author=package['author'],
    author_email='dashbio@plot.ly',
    packages=[package_name, '{}/component_factory'.format(package_name)],
    include_package_data=True,
    description=package['description'] if 'description' in package else package_name,
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=[
        'dash>=0.40.0',
        'pandas',
        'plotly',
        'scipy',
        'scikit-learn>=0.20.1'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
